/* Terraform - (C) 1997-1999 Robert Gasch (Robert_Gasch@peoplesoft.com)
 *  - www.peoplesoft.com/peoplepages/g/robert_gasch/terraform/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite s_HBOffs_HBOff0,
 * Boston, MA 02111-1s_HBOff07, USA.
 */


#include "TFBaseDialog.h"
#include "GuiColormap.h"
#include "GuiColormapBands.h"
#include "GuiDialogOAC.h"
#include "GlobalSanityCheck.h"
#include "GlobalTrace.h"



/*
 *  constructor: initialize all data members 
 */
TFBaseDialog::TFBaseDialog (HeightField *HF, HeightFieldDraw *HFD, 
				  char *winTitle, char *paramTitle)
	        : GuiDialogOAC (winTitle, paramTitle),
		  d_vBoxOptions (TRUE, 5)
{
	SanityCheck::bailout ((!HF), "HF==NULL", "TFBaseDialog::TFBaseDialog");
	SanityCheck::bailout ((!HFD), "HFD==NULL", "TFBaseDialog::TFBaseDialog");

	GlobalTrace::trace (GlobalTrace::TRACE_FLOW, "+++ TFBaseDialog\n");

	d_HF = NULL;
	d_HFD = NULL;
	d_HFO = NULL;
}


/*
 *  destructor: clean up 
 */
TFBaseDialog::~TFBaseDialog ()
{
	if (d_HFO)
		delete d_HFO;

	GlobalTrace::trace (GlobalTrace::TRACE_FLOW, "--- TFBaseDialog\n");
}


/*
 *  setHFobjs: set the HF objects we operate on and generate a scaled 
 * 	down version for the preview 
 */
void TFBaseDialog::setHFobjs (HeightField *HF, HeightFieldDraw *HFD)
{
	SanityCheck::bailout ((!HF), "HF==NULL", "TFBaseDialog::setHFobjs");
	SanityCheck::bailout ((!HFD), "HFD==NULL", "TFBaseDialog::setHFobjs");

	if (HF!=d_HF || HFD!=d_HFD)
		{
		if (d_HFO)
			delete d_HFO;
		d_HF = HF;
		d_HFD = HFD;
		d_HFO = new HeightFieldOps (d_HF);
		}
}


